#include "automation.h"
#include "esphome/core/log.h"

namespace esphome::sensor {

static const char *const TAG = "sensor.automation";

}  // namespace esphome::sensor
